@@ -5,6 +5,9 @@
 #include <string.h>
 #include <math.h>
 #include <time.h>
+#ifndef _WIN32
+#include <sys/time.h>
+#endif
 #include <locale.h>
 #include <sqlite3.h>
 #include "compat.h"
